==============
Sphinx-Gallery
==============

.. image:: https://travis-ci.org/sphinx-gallery/sphinx-gallery.svg?branch=master
    :target: https://travis-ci.org/sphinx-gallery/sphinx-gallery

.. image:: https://readthedocs.org/projects/sphinx-gallery/badge/?version=latest
    :target: https://sphinx-gallery.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image::     https://ci.appveyor.com/api/projects/status/github/sphinx-gallery/sphinx-gallery?branch=master&svg=true
    :target: https://ci.appveyor.com/project/sphinx-gallery/sphinx-gallery/history


A Sphinx extension that builds an HTML version of any Python
script and puts it into an examples gallery.

.. image:: doc/_static/demo.png
   :width: 80%
   :alt: A demo of a gallery generated by Sphinx-Gallery

Who uses Sphinx-Gallery
=======================

* `Sphinx-Gallery <https://sphinx-gallery.readthedocs.io/en/latest/auto_examples/index.html>`_
* `Scikit-learn <http://scikit-learn.org/dev/auto_examples/index.html>`_
* `Nilearn <https://nilearn.github.io/auto_examples/index.html>`_
* `MNE-python <https://www.martinos.org/mne/stable/auto_examples/index.html>`_
* `PyStruct <https://pystruct.github.io/auto_examples/index.html>`_
* `GIMLi <http://www.pygimli.org/_examples_auto/index.html>`_
* `Nestle <https://kbarbary.github.io/nestle/examples/index.html>`_
* `pyRiemann <https://pythonhosted.org/pyriemann/auto_examples/index.html>`_
* `scikit-image <http://scikit-image.org/docs/dev/auto_examples/>`_
* `Astropy <http://docs.astropy.org/en/stable/generated/examples/index.html>`_
* `SunPy <http://docs.sunpy.org/en/stable/generated/gallery/index.html>`_
* `PySurfer <https://pysurfer.github.io/>`_
* `Matplotlib <https://matplotlib.org/index.html>`_ `Examples <https://matplotlib.org/gallery/index.html>`_ and `Tutorials  <https://matplotlib.org/tutorials/index.html>`__
* `PyTorch tutorials <http://pytorch.org/tutorials>`_
* `Cartopy <http://scitools.org.uk/cartopy/docs/latest/gallery/>`_

Installation
============

Install via ``pip``
-------------------

You can do a direct install via pip by using:

.. code-block:: bash

    $ pip install sphinx-gallery

Sphinx-Gallery will not manage its dependencies when installing, thus
you are required to install them manually. Our minimal dependencies
are:

* Sphinx >= 1.5
* Matplotlib
* Pillow

Sphinx-Gallery has also support for packages like:

* Seaborn
* Mayavi

Install as a developer
----------------------

You can get the latest development source from our `Github repository
<https://github.com/sphinx-gallery/sphinx-gallery>`_. You need
``setuptools`` installed in your system to install Sphinx-Gallery.

You will also need to install the dependencies listed above and `pytest`

To install everything do:

.. code-block:: bash

    $ git clone https://github.com/sphinx-gallery/sphinx-gallery
    $ cd sphinx-gallery
    $ pip install -r requirements.txt
    $ pip install -e .

In addition, you will need the following dependencies to build the
``sphinx-gallery`` documentation:

* Scipy
* Seaborn
